@@ -1,6 +1,10 @@
 # 插件的配置文件
+from nonebot import get_driver
 from pydantic import Extra, BaseModel
 
 
 class Config(BaseModel, extra=Extra.ignore):
-    gshisbanner_forward_length: int = 10
\ No newline at end of file
+    gshisbanner_forward_length: int = 10
+
+
+config = Config.parse_obj(get_driver().config.dict())
\ No newline at end of file
